Changelog
=========

## unreleased

## 0.4 - 2025-03-03

## Added

- Support for check conditions
- Validate check configs
- Validate values from Icinga2

## Fixed

- Issue with simple thresholds
- Issue with reported state of grouped values

## 0.3. - 2025-02-28

## Added

- Load settings with pydantic settings
- docker compose file
- Check script

## Changed

- Change container build and set default config files
- Update documentation

## Removed

- Removed the support for dynaconf

## 0.2.0 - 2025-02-22

### Added

- Add doc
- Add ci pipeline
- Add container builds

### Changed

- Rename prom2icinga to prom2icinga2

## 0.1.0 - 2025-02-21

### Added

- Initial PoC release
